//
//  Log.h
//  iStrip
//
//  Created by Joar Wingfors on Fri Jan 31 2003.
//  Copyright (c) 2003 joar.com. All rights reserved.
//

#import <Foundation/Foundation.h>

// Logs will only be printed to the console if the user defaults
// key "LogLevel" is set to a value equal to or higher than the
// log facility in question. Errors (0) are always printed, but
// the other levels requires the key to be set: warning (1),
// info (2), debug (3).
// Example: "defaults write com.joar.iStrip LogLevel 2"

@interface Log : NSObject

// Messages sent to log: will always be logged to the Console
// "Error: " will be prepended to the log message
+ (void) errorFormat:(NSString *) format, ...;
+ (void) error:(NSString *) msg;

// Messages sent to these three methods will only be logged
// if they match the LogLevel specified by the user.
// "Warning: " / "Info: " / "Debug: " will be prepended to the log message
+ (void) warningFormat:(NSString *) format, ...;
+ (void) warning:(NSString *) msg;

+ (void) infoFormat:(NSString *) format, ...;
+ (void) info:(NSString *) msg;

+ (void) debugFormat:(NSString *) format, ...;
+ (void) debug:(NSString *) msg;

@end
